@@ -23,8 +23,9 @@ def _screenMainLoop(s):
             resizeCheck = int(round(time.time() * 1000))
             s.refresh(f=True)
         try:
-            sizeOfQueue = s.q.qsize()
+            #sizeOfQueue = s.q.qsize()
             msg = s.q.get(timeout=0.5)
+            print(sizeOfQueue)
         except Empty:
             s.refresh()
         if isinstance(msg, list) and len(msg) > 0:
@@ -32,7 +33,7 @@ def _screenMainLoop(s):
                 return
             elem = s.getElem(msg[0])
             if elem:
-                elem.receive(msg[1:])
+                elem.receive(msg)
                 t = int(round(time.time() * 1000))
                 if (sizeOfQueue < 1000 and t - s.lastRefresh > 30) or t - s.lastRefresh > 1000:
                     s.lastRefresh = t
@@ -95,16 +96,18 @@ class Server:
 
 
 def linePrinter(cs: line):
-    for i in range(50, 300):
-        cs["v"].set("xxx" + str(i) * 3)
-        time.sleep(2.2)
+    while True:
+        for i in range(300000):
+            cs["v"].set(str(i))
+            #time.sleep(2.2)
 
 
 def linePrinter2(cs: line):
     cs.total = 200
-    for i in range(0, 2000):
-        cs["count"].add(1)
-        time.sleep(1.2)
+    while True:
+        for i in range(0, 2000):
+            cs["count"].add(1)
+            #time.sleep(1.2)
 
 
 def bufferPrinter(bs: buffer):
@@ -125,6 +128,8 @@ if __name__ == "__main__":
     ss.start()
 
     pr = [Process(target=linePrinter, args=[l1]),
+          Process(target=linePrinter2, args=[l2]),
+          Process(target=linePrinter2, args=[l2]),
           Process(target=linePrinter2, args=[l2]),
           Process(target=bufferPrinter, args=[upperConsole]),
           Process(target=bufferPrinter, args=[lowerConsole])
